Re-exports
pub use crate::write_sink::WriteSink;
Structs
- Ceph
Object - IoCtx
- Owns a ioctx handle
- Pool
- Helper to iterate over pool objects
- Rados
- Owns a rados handle
- Rados
Version - The version of the librados library.
- Read
Operation - A helper to create rados read operation An object read operation stores a number of operations which can be executed atomically.
- Write
Operation - A helper to create rados write operation An object write operation stores a number of operations which can be executed atomically.
- XAttr
- A rados object extended attribute with name and value. Can be iterated over
Enums
Functions
- ceph_
version - Ceph version - Ceph during the make release process generates the version
number along with
the github hash of the release and embeds the hard coded value into
ceph.pywhich is the the default ceph utility. - ceph_
version_ parse - This version call parses the
ceph -soutput. It does not needsudorights likeceph_versiondoes since it pulls from the admin socket. - connect_
to_ ceph - Connect to a Ceph cluster and return a connection handle rados_t
- connect_
to_ ceph_ async - Non-blocking wrapper for
connect_to_ceph - destroy_
rados_ ioctx_ async - The lifetime of
IoCtxends up after destroy_rados_ioctx, so just move it away. - disconnect_
from_ ceph_ async - The lifetime of
Radosends up after disconnect_from_ceph, so just move it away. - rados_
libversion - Get the version of librados.