pub fn with_completion<F>(ioctx: &IoCtx, f: F) -> RadosResult<Completion<'_>>Expand description
Completions are only created via this wrapper, in order to ensure that the Completion struct is only constructed around ‘armed’ rados_completion_t instances (i.e. those that have been used to start an I/O).