pub struct CephClient { /* private fields */ }Expand description
A CephClient is a struct that handles communicating with Ceph in a nicer, Rustier way
let client = CephClient::new("admin", "/etc/ceph/ceph.conf")?;
let tree = client.osd_tree()?;Implementations
Sourceimpl CephClient
impl CephClient
pub fn new<T1: AsRef<str>, T2: AsRef<str>>( user_id: T1, config_file: T2, ) -> Result<CephClient, RadosError>
pub fn simulate(self) -> Self
pub fn osd_out(&self, osd_id: u64) -> Result<(), RadosError>
pub fn osd_crush_remove(&self, osd_id: u64) -> Result<(), RadosError>
Sourcepub fn osd_pool_get(
&self,
pool: &str,
choice: &PoolOption,
) -> Result<String, RadosError>
pub fn osd_pool_get( &self, pool: &str, choice: &PoolOption, ) -> Result<String, RadosError>
Query a ceph pool.
Sourcepub fn osd_pool_set(
&self,
pool: &str,
key: &str,
value: &str,
) -> Result<(), RadosError>
pub fn osd_pool_set( &self, pool: &str, key: &str, value: &str, ) -> Result<(), RadosError>
Set a pool value
Sourcepub fn osd_set(&self, key: OsdOption, force: bool) -> Result<(), RadosError>
pub fn osd_set(&self, key: OsdOption, force: bool) -> Result<(), RadosError>
Can be used to set options on an OSD
let client = CephClient::new("admin", "/etc/ceph/ceph.conf")?;
client.osd_set(OsdOption::NoDown, false)?;Sourcepub fn osd_unset(&self, key: OsdOption) -> Result<(), RadosError>
pub fn osd_unset(&self, key: OsdOption) -> Result<(), RadosError>
Can be used to unset options on an OSD
let client = CephClient::new("admin", "/etc/ceph/ceph.conf")?;
client.osd_unset(OsdOption::NoDown)?;pub fn osd_tree(&self) -> Result<CrushTree, RadosError>
Sourcepub fn status(&self) -> Result<String, RadosError>
pub fn status(&self) -> Result<String, RadosError>
Get cluster status
Sourcepub fn mon_dump(&self) -> Result<MonDump, RadosError>
pub fn mon_dump(&self) -> Result<MonDump, RadosError>
List all the monitors in the cluster and their current rank
Sourcepub fn mon_quorum(&self) -> Result<String, RadosError>
pub fn mon_quorum(&self) -> Result<String, RadosError>
Get the mon quorum
Sourcepub fn version(&self) -> Result<CephVersion, RadosError>
pub fn version(&self) -> Result<CephVersion, RadosError>
Show mon daemon version
pub fn osd_pool_quota_get(&self, pool: &str) -> Result<u64, RadosError>
pub fn auth_del(&self, osd_id: u64) -> Result<(), RadosError>
pub fn osd_rm(&self, osd_id: u64) -> Result<(), RadosError>
pub fn osd_create(&self, id: Option<u64>) -> Result<u64, RadosError>
pub fn mgr_auth_add(&self, mgr_id: &str) -> Result<(), RadosError>
pub fn osd_auth_add(&self, osd_id: u64) -> Result<(), RadosError>
Sourcepub fn auth_get_key(
&self,
client_type: &str,
id: &str,
) -> Result<String, RadosError>
pub fn auth_get_key( &self, client_type: &str, id: &str, ) -> Result<String, RadosError>
Get a ceph-x key. The id parameter can be either a number or a string depending on the type of client so I went with string.
Sourcepub fn osd_crush_add(
&self,
osd_id: u64,
weight: f64,
host: &str,
) -> Result<(), RadosError>
pub fn osd_crush_add( &self, osd_id: u64, weight: f64, host: &str, ) -> Result<(), RadosError>
add or update crushmap position and weight for an osd
Sourcepub fn osd_crush_reweight(
&self,
osd_id: u64,
weight: f64,
) -> Result<(), RadosError>
pub fn osd_crush_reweight( &self, osd_id: u64, weight: f64, ) -> Result<(), RadosError>
reweight an osd in the CRUSH map
Sourcepub fn osd_safe_to_destroy(&self, osd_id: u64) -> bool
pub fn osd_safe_to_destroy(&self, osd_id: u64) -> bool
check if a single osd is safe to destroy/remove
pub fn mgr_dump(&self) -> Result<MgrDump, RadosError>
pub fn mgr_fail(&self, mgr_id: &str) -> Result<(), RadosError>
pub fn mgr_list_modules(&self) -> Result<Vec<String>, RadosError>
pub fn mgr_list_services(&self) -> Result<Vec<String>, RadosError>
pub fn mgr_enable_module( &self, module: &str, force: bool, ) -> Result<(), RadosError>
pub fn mgr_disable_module(&self, module: &str) -> Result<(), RadosError>
pub fn mgr_metadata(&self) -> Result<Vec<MgrMetadata>, RadosError>
pub fn osd_metadata(&self) -> Result<Vec<OsdMetadata>, RadosError>
pub fn mgr_count_metadata( &self, property: &str, ) -> Result<HashMap<String, u64>, RadosError>
pub fn mgr_versions(&self) -> Result<HashMap<String, u64>, RadosError>
pub fn run_command(&self, command: MonCommand<'_>) -> Result<String, RadosError>